@@ -265,7 +265,11 @@ void show_edit_dialog(MicrofeedSubscriber* subscriber, GtkWindow* parent, const
 			gtk_widget_set_sensitive(mode_button, FALSE);
 			gtk_dialog_add_action_widget(GTK_DIALOG(edit_dialog->dialog), mode_button, 1);
 		}
+#ifdef MAEMO_CHANGES
+		edit_dialog->edit_button = hildon_button_new_with_text(HILDON_SIZE_AUTO_WIDTH | HILDON_SIZE_FINGER_HEIGHT, HILDON_BUTTON_ARRANGEMENT_VERTICAL, "Edit", NULL);
+#else
 		edit_dialog->edit_button = gtk_button_new_from_stock(GTK_STOCK_EDIT);
+#endif
 		gtk_widget_set_sensitive(edit_dialog->edit_button, FALSE);
 		gtk_dialog_add_action_widget(GTK_DIALOG(edit_dialog->dialog), edit_dialog->edit_button, 2);
 #ifndef MAEMO_CHANGES
@@ -335,7 +339,7 @@ void show_edit_dialog(MicrofeedSubscriber* subscriber, GtkWindow* parent, const
 		g_signal_connect(selection, "changed", G_CALLBACK(on_selection_changed), edit_dialog);
 #endif
 	
-		if (microfeed_subscriber_subscribe_feed(subscriber, publisher, MICROFEED_FEED_URI_SETTINGS, &callbacks, settings_subscribed, edit_dialog)) {
+		if (microfeed_subscriber_subscribe_feed(subscriber, publisher, MICROFEED_FEED_URI_SETTINGS, &callbacks, edit_dialog, settings_subscribed, edit_dialog)) {
 			gtk_widget_show_all(edit_dialog->dialog);
 			
 			while ((response = gtk_dialog_run(GTK_DIALOG(edit_dialog->dialog))) != GTK_RESPONSE_DELETE_EVENT && response != GTK_RESPONSE_NONE) {
@@ -384,7 +388,7 @@ void show_edit_dialog(MicrofeedSubscriber* subscriber, GtkWindow* parent, const
 		free(publisher_part);
 		free(provider_part);
 	
-		microfeed_subscriber_unsubscribe_feed(subscriber, publisher, MICROFEED_FEED_URI_SETTINGS, NULL, NULL);
+		microfeed_subscriber_unsubscribe_feed(subscriber, publisher, MICROFEED_FEED_URI_SETTINGS, &callbacks, edit_dialog, NULL, NULL);
 	}
 	
 	microfeed_configuration_free(configuration);
